@@ -1,5 +1,5 @@
 package SVG::Estimate::Path::Arc;
-$SVG::Estimate::Path::Arc::VERSION = '1.0008';
+$SVG::Estimate::Path::Arc::VERSION = '1.0100';
 use Moo;
 use Math::Trig qw/pi acos deg2rad rad2deg/;
 use Clone qw/clone/;
@@ -8,7 +8,6 @@ use strict;
 extends 'SVG::Estimate::Path::Command';
 with 'SVG::Estimate::Role::Pythagorean';
 with 'SVG::Estimate::Role::SegmentLength';
-with 'SVG::Estimate::Role::EndToPoint';
 
 =head1 NAME
 
@@ -16,14 +15,15 @@ SVG::Estimate::Path::Arc - Handles estimating arcs.
 
 =head1 VERSION
 
-version 1.0008
+version 1.0100
 
 =head1 SYNOPSIS
 
  my $arc = SVG::Estimate::Path::Arc->new(
     transformer     => $transform,
     start_point     => [13, 19],
-    point           => [45,13],
+    x               => 45,
+    y               => 13,
     rx              => 1,
     ry              => 3,
     x_axis_rotation => 0,
@@ -45,9 +45,13 @@ Constructor.
 
 =over
 
-=item point
+=item x
 
-An array ref containing two floats that represent a point. 
+The x coordinate for the end-point of the arc.
+
+=item y
+
+The y coordinate for the end-point of the arc.
 
 =item rx
 
@@ -98,7 +102,12 @@ has sweep_flag => (
     required    => 1,
 );
 
-has point => (
+has x => (
+    is          => 'ro',
+    required    => 1,
+);
+
+has y => (
     is          => 'ro',
     required    => 1,
 );
@@ -149,9 +158,10 @@ sub BUILDARGS {
             $start = $point;
         }
         ##Restore the original start point in the viewport coordinate system
-        $args->{start_point} = $view_start_point;
-        $args->{end_point} = $point;
-        $args->{length}    = $length;
+        $args->{start_point}   = $view_start_point;
+        $args->{end_point}     = $point;
+        $args->{shape_length}  = $length;
+        $args->{travel_length} = 0;
         return $args;
     }
     $class->endpoint_to_center($args);
@@ -162,7 +172,8 @@ sub BUILDARGS {
     $args->{max_x}  = $start->[0] > $end->[0] ? $start->[0] : $end->[0];
     $args->{min_y}  = $start->[1] < $end->[1] ? $start->[1] : $end->[1];
     $args->{max_y}  = $start->[1] > $end->[1] ? $start->[1] : $end->[1];
-    $args->{length} = $class->segment_length($args, 0, 1, $start, $end, 1e-4, 5, 0);
+    $args->{shape_length}  = $class->segment_length($args, 0, 1, $start, $end, 1e-4, 5, 0);
+    $args->{travel_length} = 0;
     return $args;
 }
 
@@ -172,8 +183,8 @@ sub endpoint_to_center {
     my $rotr = deg2rad($args->{x_axis_rotation});
     my $cosr = cos $rotr;
     my $sinr = sin $rotr;
-    my $dx   = ($args->{start_point}->[0] - $args->{point}->[0] ) / 2; #*
-    my $dy   = ($args->{start_point}->[1] - $args->{point}->[1] ) / 2; #*
+    my $dx   = ($args->{start_point}->[0] - $args->{x}) / 2; #*
+    my $dy   = ($args->{start_point}->[1] - $args->{y}) / 2; #*
 
     my $x1prim = $cosr * $dx + $sinr * $dy; #*
     my $y1prim = -1*$sinr * $dx + $cosr * $dy; #*
@@ -199,8 +210,8 @@ sub endpoint_to_center {
     my $cyprim = -1 *$c * $ry * $x1prim / $rx;
 
     $args->{_center} = [
-        ($cosr * $cxprim - $sinr * $cyprim) + ( ($args->{start_point}->[0] + $args->{point}->[0]) / 2 ),
-        ($sinr * $cxprim + $cosr * $cyprim) + ( ($args->{start_point}->[1] + $args->{point}->[1]) / 2 )
+        ($cosr * $cxprim - $sinr * $cyprim) + ( ($args->{start_point}->[0] + $args->{x}) / 2 ),
+        ($sinr * $cxprim + $cosr * $cyprim) + ( ($args->{start_point}->[1] + $args->{y}) / 2 )
     ];
 
     ##**
