@@ -1,5 +1,5 @@
 package SVG::Estimate::Path::Command;
-$SVG::Estimate::Path::Command::VERSION = '1.0008';
+$SVG::Estimate::Path::Command::VERSION = '1.0100';
 use Moo;
 with 'SVG::Estimate::Role::Round';
 
@@ -10,7 +10,7 @@ SVG::Estimate::Path::Command - Base class for all path calculations.
 
 =head1 VERSION
 
-version 1.0008
+version 1.0100
 
 =head1 DESCRIPTION
 
@@ -67,13 +67,24 @@ has end_point => (
     required    => 1,
 );
 
-=head2 length ( )
+=head2 shape_length ( )
 
-Returns the total length of the vector in the path command.
+Returns the total shape length of the vector in the path command.
 
 =cut
 
-has length => (
+has shape_length => (
+    is          => 'ro',
+    required    => 1,
+);
+
+=head2 travel_length ( )
+
+Returns the total travel length of the vector in the path command.
+
+=cut
+
+has travel_length => (
     is          => 'ro',
     required    => 1,
 );
