@@ -1,5 +1,5 @@
 package SVG::Estimate::Path::CubicBezier;
-$SVG::Estimate::Path::CubicBezier::VERSION = '1.0008';
+$SVG::Estimate::Path::CubicBezier::VERSION = '1.0100';
 use Moo;
 use List::Util qw/min max/;
 use Clone qw/clone/;
@@ -15,7 +15,7 @@ SVG::Estimate::Path::CubicBezier - Handles estimating cubic bezier curves.
 
 =head1 VERSION
 
-version 1.0008
+version 1.0100
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,8 @@ sub BUILDARGS {
     $args->{min_y} = $start->[1] < $end->[1] ? $start->[1] : $end->[1];
     $args->{max_y} = $start->[1] > $end->[1] ? $start->[1] : $end->[1];
 
-    $args->{length} = $class->segment_length($args, 0, 1, $start, $end, 1e-4, 5, 0);
+    $args->{shape_length}  = $class->segment_length($args, 0, 1, $start, $end, 1e-4, 5, 0);
+    $args->{travel_length} = 0;
 
     return $args;
 }
