@@ -1,5 +1,5 @@
 package SVG::Estimate::Path::Lineto;
-$SVG::Estimate::Path::Lineto::VERSION = '1.0008';
+$SVG::Estimate::Path::Lineto::VERSION = '1.0100';
 use Moo;
 
 extends 'SVG::Estimate::Path::Command';
@@ -11,7 +11,7 @@ SVG::Estimate::Path::Lineto - Handles estimating diagonal lines.
 
 =head1 VERSION
 
-version 1.0008
+version 1.0100
 
 =head1 SYNOPSIS
 
@@ -58,11 +58,12 @@ sub BUILDARGS {
     }
     $args->{start_point}  = $args->{start_point};
     $args->{end_point}    = $point;
-    $args->{length}       = $class->pythagorean($args->{start_point}, $args->{end_point});
     $args->{min_x}        = $args->{start_point}[0] < $point->[0] ? $args->{start_point}[0] : $point->[0];
     $args->{min_y}        = $args->{start_point}[1] < $point->[1] ? $args->{start_point}[1] : $point->[1];
     $args->{max_x}        = $args->{start_point}[0] > $point->[0] ? $args->{start_point}[0] : $point->[0];
     $args->{max_y}        = $args->{start_point}[1] > $point->[1] ? $args->{start_point}[1] : $point->[1];
+    $args->{shape_length}       = $class->pythagorean($args->{start_point}, $args->{end_point});
+    $args->{travel_length}      = 0;
     return $args;
 }
 
