@@ -1,5 +1,5 @@
 package SVG::Estimate::Path::Moveto;
-$SVG::Estimate::Path::Moveto::VERSION = '1.0008';
+$SVG::Estimate::Path::Moveto::VERSION = '1.0100';
 use Moo;
 
 extends 'SVG::Estimate::Path::Command';
@@ -11,7 +11,7 @@ SVG::Estimate::Path::Moveto - Handles estimating non-drawn movement.
 
 =head1 VERSION
 
-version 1.0008
+version 1.0100
 
 =head1 SYNOPSIS
 
@@ -21,7 +21,7 @@ version 1.0008
     point           => [45,13],
  );
 
- my $length = $move->length;
+ my $travel_length = $move->travel_length;
 
 =head1 INHERITANCE
 
@@ -58,11 +58,12 @@ sub BUILDARGS {
     }
     $args->{start_point}  = $args->{start_point};
     $args->{end_point}    = $point;
-    $args->{length}       = $class->pythagorean($args->{start_point}, $args->{end_point});
     $args->{min_x}        = $point->[0];
     $args->{min_y}        = $point->[1];
     $args->{max_x}        = $point->[0];
     $args->{max_y}        = $point->[1];
+    $args->{travel_length} = $class->pythagorean($args->{start_point}, $args->{end_point});
+    $args->{shape_length}  = 0;
     return $args;
 }
 
