@@ -1,5 +1,5 @@
 package SVG::Estimate::Path::QuadraticBezier;
-$SVG::Estimate::Path::QuadraticBezier::VERSION = '1.0008';
+$SVG::Estimate::Path::QuadraticBezier::VERSION = '1.0100';
 use Moo;
 use List::Util qw/min max/;
 use Clone qw/clone/;
@@ -13,7 +13,7 @@ SVG::Estimate::Path::QuadraticBezier - Handles estimating quadratic bezier curve
 
 =head1 VERSION
 
-version 1.0008
+version 1.0100
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,8 @@ sub BUILDARGS {
         $args->{control} = $args->{transformer}->transform($args->{control});
     }
     $args->{end_point} = clone $args->{point};
-    $args->{length} = $class->_calculate_length($args);
+    $args->{shape_length}  = $class->_calculate_length($args);
+    $args->{travel_length} = 0;
     ##Bouding box points approximated by the control points.
     $args->{min_x} = min $args->{start_point}->[0], $args->{control}->[0], $args->{point}->[0];
     $args->{max_x} = max $args->{start_point}->[0], $args->{control}->[0], $args->{point}->[0];
